"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Polling = void 0;
const debug = require("debug");
const EventTransport_1 = require("./EventTransport");
class Polling extends EventTransport_1.EventTransport {
    constructor() {
        super(...arguments);
        this.log = debug("tg-io:polling");
    }
    async start(handler) {
        if (this.state === EventTransport_1.EventTransportState.Working) {
            return;
        }
        this.log("started");
        let offset;
        this.state = EventTransport_1.EventTransportState.Working;
        return new Promise((resolve, reject) => {
            while (this.state === EventTransport_1.EventTransportState.Working) {
                this.handleUpdates(handler, reject, offset).catch(reject);
            }
            resolve();
        });
    }
    async handleUpdates(handler, onerror, offset) {
        let updates = (await this.api.callMethod("getUpdates", offset === undefined ? {} : { offset }));
        Promise.all(updates.result.map(async (update) => {
            return await handler.handle(update);
        })).catch(onerror);
        return offset + updates.result.length;
    }
    stop() {
        if (this.state !== EventTransport_1.EventTransportState.Working)
            return;
        this.log("stopped");
        this.state = EventTransport_1.EventTransportState.Stopped;
    }
}
exports.Polling = Polling;
